pro aeronet_aot_ext,mode,y_input,m_input,d_input,time,am,year_count,pressure_corr,rel_press,ifit,cimel_chan,l0_fit,l1_fit,l2_fit,no2_corr, $	; input
		v0_corr,cimel,v0_corr_cimel,aeronet_aot,ln_wav_mfrsr,aot_mfrsr, aer340cor,aer380cor,aer440cor,aer500cor, delta_aot_fit,sigma_aot_fit


;		WARNING
;       input tr440 and tr500 are correct only for AERONET CIMELS (101,89, 37) (#94 is OK)

;		MODIFIED
;	04/20/07 - 3 wavelength lagrangian interpolation (cimel_chan=3)  l0_fit,l1_fit,l2_fit   
;	05/20/05 - 3 wavelength lagrangian interpolation (cimel_chan=3)  l0_fit,l1_fit,l2_fit   
;	05/10/05 - to prevent non-positive aer340cor,aer380cor,aer440cor,aer500cor               
;	03/08/05 - to add V0 correction (CIMEL and channel specific)                             
;	03/04/05 - to output corrcted AERONET AOT (aer340cor,aer380cor,aer440cor,aer500cor)
;	02/28/05 - to generalize linear interpolation for any 2 wavelengths: l0_fit,l1_fit

;		INPUT
; aeronet_aot(0,1,2,3) 	i uncorrected AERONET AOT (from the web site time interpolated to MFRSR measurements)
; l0_fit,l1_fit		i 	linear interpolation wavelength indices (0-340, 1-380, 2-440, 3-500)
; no2_corr	l eq 'yes' then apply NO2 correction for 1 DU
; aeronet_aot(0,1,2,3)   i uncorrected AERONET AOT interpolated to UV-MFRSR time
; ln_wav_mfrsr		i all wavelengths within boundaries of specific UV-MFRSR channel (lmin , ...,lmax)

;		OUTPUT
; cimel		o CIMEL number
; aot_mfrsr(..)     o corrected aeronet_aot(...) spectrally interpolated to ln_wav_mfrsr   
; aer340cor     o  corrected aeronet_aot(0)  (for pressure, V0 , NO2, etc) referred to central wavelength (l_cent) of CIMEL 340nm filter
; aer380cor     o  corrected aeronet_aot(1)  (for pressure, V0 , NO2, etc) referred to central wavelength (l_cent) of CIMEL 380nm filter
; aer440cor     o  corrected aeronet_aot(2)  (for pressure, V0 , NO2, etc) referred to central wavelength (l_cent) of CIMEL 440nm filter
; aer500cor     o  corrected aeronet_aot(3)  (for pressure, V0 , NO2, etc) referred to central wavelength (l_cent) of CIMEL 500nm filter


nlam=n_elements(ln_wav_mfrsr)
aot_mfrsr=dblarr(nlam)

;print, 'aeronet_aot_ext: aeronet_aot',aeronet_aot
; Ozone climatology for Goddard as used by AERONET
; ozone absorption coefficient @340nm  0.0254 per atmcm
; ozone absorption coefficient @380nm  0.0000 per atmcm

;	Standard AERONET site Pressures 
; GSFC,  NASA Bld 33                            = 0.993769
; MAuna Loa                                     = 0.654    

;    			Instrument specific Rayleigh and wavelength correction

CASE 1  OF		;    1 is equivalent to true  and is matched against each of the logical conditionals

(year_count ge 2002.7419) and (year_count le 2002.9609 ):    BEGIN
tr340=0.705114 & tr380=0.445221			; CIMEL #89 corrected for GSFC pressure
pres_aeronet=0.993769
ln_wav=alog(0.1+[340.0,379.4,440.0,500.0])	; and lam plus 0.1 for vacuum wavelength scale
cimel=89
v0_corr_cimel=[+0.000,+0.000,+0.000,+0.000] 	; [340,380,440,500] is not known for CIMEL #101 prior to deployment
								END
(year_count ge 2002.9637) and (year_count le 2003.0931):	BEGIN       
tr340=0.705989 & tr380=0.445221 & tr440=0.239505 & tr500=0.141753	; CIMEL #94 corrected for GSFC pressure
pres_aeronet=0.993769 
ln_wav=alog(0.1+[339.9,379.4,440.0,500.0])	; and lam plus 0.1 for vacuum wavelength scale
cimel=94
v0_corr_cimel=[+0.000,+0.000,+0.000,+0.000] 	; [340,380,440,500] is not known for CIMEL #101 prior to deployment
								END
(year_count ge 2003.0958) and (year_count le 2003.1971): 	BEGIN       
tr340=0.702495 & tr380=0.439877			; CIMEL #37 corrected for GSFC pressure
pres_aeronet=0.993769

ln_wav=alog(0.1+[340.3,380.5,440.0,500.0])	; and lam plus 0.1 for vacuum wavelength scale
cimel=37
v0_corr_cimel=[+0.000,+0.000,+0.000,+0.000] 	; [340,380,440,500] is not known for CIMEL #101 prior to deployment
								END
(year_count ge 2003.1998) and (year_count le 2003.3615): 	BEGIN       
tr340=0.702495 & tr380=0.441327			; CIMEL #101 corrected for GSFC pressure
pres_aeronet=0.993769

ln_wav=alog(0.1+[340.3,380.2,440.0,500.0])	; and lam plus 0.1 for vacuum wavelength scale
cimel=101
v0_corr_cimel=[+0.000,+0.000,+0.000,+0.000] 	; [340,380,440,500] is not known for CIMEL #101 prior to deployment
								END
(year_count ge 2003.3641) and (year_count le 2003.4600): 	BEGIN       
;Date: Thu, 5 Jun 2003 19:09:22 GMT 
;From: Ilya Slutsker <ilya@ltpmailx.gsfc.nasa.gov> 
;To: krotkov@chescat.gsfc.nasa.gov 
;Wave = 1.021400   Rayleigh = 0.007897  at elevation 50.000000  in GSFC
;Wave = 0.870100   Rayleigh = 0.015058  at elevation 50.000000  in GSFC
;Wave = 0.675600   Rayleigh = 0.041842  at elevation 50.000000  in GSFC
;Wave = 0.440600   Rayleigh = 0.239505  at elevation 50.000000  in GSFC
;Wave = 0.500600   Rayleigh = 0.141753  at elevation 50.000000  in GSFC
;Wave = 0.936100   Rayleigh = 0.011217  at elevation 50.000000  in GSFC
;Wave = 0.379400   Rayleigh = 0.445221  at elevation 50.000000  in GSFC
;Wave = 0.339900   Rayleigh = 0.705989  at elevation 50.000000  in GSFC

tr340=0.705989 & tr380=0.445221 & tr440=0.239505 & tr500=0.141753	; CIMEL #94 corrected for GSFC pressure
pres_aeronet=0.993769

ln_wav=alog(0.1+[339.9,379.4,440.0,500.0])	; and lam plus 0.1 for vacuum wavelength scale
cimel=94 
v0_corr_cimel=[+0.000,+0.000,+0.000,+0.000] 	; [340,380,440,500] is not known for CIMEL #101 prior to deployment
								END
(year_count ge 2003.4626) and (year_count le 2003.5613): 	BEGIN       
tr340=0.705114 & tr380=0.445221			; CIMEL #89 corrected for GSFC pressure
pres_aeronet=0.993769

ln_wav=alog(0.1+[340.0,379.4,440.0,500.0])	; and lam plus 0.1 for vacuum wavelength scale
cimel=89 
v0_corr_cimel=[+0.000,+0.000,+0.000,+0.000] 	; [340,380,440,500] is not known for CIMEL #101 prior to deployment
								END
(year_count ge 2003.5640) and (year_count le 2003.7721): 	BEGIN       
tr340=0.702495 & tr380=0.441327			; CIMEL #101 corrected for GSFC pressure
pres_aeronet=0.993769

ln_wav=alog(0.1+[340.3,380.2,440.0,500.0])	; and lam plus 0.1 for vacuum wavelength scale
cimel=101
v0_corr_cimel=[+0.000,+0.000,+0.000,+0.000] 	; [340,380,440,500] is not known for CIMEL #101 prior to deployment
								END
(year_count ge 2003.7748) and (year_count le 2003.7913): 	BEGIN       
tr340=0.705989 & tr380=0.444731			; CIMEL #101 corrected for GSFC pressure
tr440=0.239505 & tr500=0.141753	; CIMEL #94 corrected for GSFC pressure
pres_aeronet=0.993769

ln_wav=alog(0.1+[340.3,380.2,440.0,500.0])	; and lam plus 0.1 for vacuum wavelength scale
cimel=101
v0_corr_cimel=[+0.000,+0.000,+0.000,+0.000] 	; [340,380,440,500] is not known for CIMEL #101 prior to deployment
								END
(year_count ge 2003.7939) and (year_count le 2003.9556): 	BEGIN       
tr340=0.705989 & tr380=0.441811			; CIMEL #89 corrected for GSFC pressure
tr440=0.239505 & tr500=0.141753	; CIMEL #94 corrected for GSFC pressure
pres_aeronet=0.993769

ln_wav=alog(0.1+[339.9,380.1,440.0,500.0])	; and lam plus 0.1 for vacuum wavelength scale
cimel=89 
v0_corr_cimel=[+0.000,+0.000,+0.000,+0.000] 	; [340,380,440,500] is not known for CIMEL #101 prior to deployment
								END
(year_count ge 2003.9583) and (year_count lt 2004.33): 		BEGIN       
tr340=0.705989 & tr380=0.445221			; CIMEL #94 corrected for GSFC pressure
tr440=0.239505 & tr500=0.141753	; CIMEL #94 corrected for GSFC pressure
pres_aeronet=0.993769

ln_wav=alog(0.1+[339.9,379.4,440.0,500.0])	; and lam plus 0.1 for vacuum wavelength scale
cimel=94 
v0_corr_cimel=[+0.000,+0.000,+0.000,+0.000] 	; [340,380,440,500] is not known for CIMEL #101 prior to deployment
								END
(year_count ge 2004.33) and (year_count lt 2004.419): 		BEGIN ;  April 29: June 1st at GSFC
tr340=0.702495 & tr380=0.439877			; CIMEL #37 corrected for GSFC pressure
tr440=0.239505 & tr500=0.141753	; CIMEL #94 corrected for GSFC pressure
pres_aeronet=0.993769

ln_wav=alog(0.1+[340.3,380.5,440.0,500.0])	; and lam plus 0.1 for vacuum wavelength scale
cimel=37
v0_corr_cimel=[+0.000,+0.000,+0.000,+0.000] 	; [340,380,440,500] is not known for CIMEL #101 prior to deployment
								END
;Date: Wed, 26 Jan 2005 17:58:19 -0500 (EST) 
;From: Ilya Slutsker <ilya@aeronet.gsfc.nasa.gov> 
;Wave = 1.019900   Rayleigh = 0.007984  at elevation 10.000000  in MAARCO
;Wave = 0.870000   Rayleigh = 0.015140  at elevation 10.000000  in MAARCO
;Wave = 0.674700   Rayleigh = 0.042280  at elevation 10.000000  in MAARCO
;Wave = 0.439600   Rayleigh = 0.242972  at elevation 10.000000  in MAARCO
;Wave = 0.500200   Rayleigh = 0.142930  at elevation 10.000000  in MAARCO
;Wave = 0.941200   Rayleigh = 0.011029  at elevation 10.000000  in MAARCO
;Wave = 0.379800   Rayleigh = 0.445490  at elevation 10.000000  in MAARCO
;Wave = 0.340100   Rayleigh = 0.707770  at elevation 10.000000  in MAARCO

(year_count ge 2004.5859) and (year_count lt 2004.753 ): 	BEGIN  ; Aug 1 - Oct 1 2004
pres_aeronet=0.999 
tr340=0.707770 & tr380=0.445490 & tr440=0.242972 & tr500=0.142930	; CIMEL #303 corrected for MAARCO (UAE) pressure (10m asl)
ln_wav=alog(0.1+[340.2,379.9,439.7,500.3])	; and lam plus 0.1 for vacuum wavelength scale
cimel=303
v0_corr_cimel=[+0.000,+0.000,+0.000,+0.000] 	; [340,380,440,500] is not known for CIMEL #303 prior to deployment
								END
;Date: Thu, 27 Jan 2005 10:03:25 -0500
;To: krotkov <krotkov@chescat.gsfc.nasa.gov>
;From: Tom Eck <teck@ltpmail.gsfc.nasa.gov>
;Subject: Re: reference CIMEL at GSFC in Nov - Dec 2004
;
;#101 - Nov 01-  Nov 08, 2004
;#89  -  Nov 09 - Dec 14, 2004
;#94 -   Dec 15 - Dec 31, 2004
;
;None of these Cimels has yet had a 2nd calibration applied yet, so 
;the Vo calibrations will eventually be adjusted. #101 will have it's 
;2nd calibration finalized next week and the data will then be 
;reprocessed assuming linear calibration change in time between the 2 Mauna Loa calibrations.
;Tom

(year_count gt 2004.834) and (year_count  le 2004.856):	BEGIN ;#101 - Nov 01-  Nov 08, 2004
pres_aeronet=0.993769

tr340=0.705989 & tr380=0.444731 			; CIMEL #101 corrected for GSFC pressure
tr440=0.239505 & tr500=0.141753	; CIMEL #94 corrected for GSFC pressure
ln_wav=alog(0.1+[340.3,380.2,440.0,500.0])	; and lam plus 0.1 for vacuum wavelength scale
cimel=101
v0_corr_cimel=[+0.000,+0.000,+0.000,+0.000] 	; [340,380,440,500] is not known for CIMEL #101 prior to deployment
							END
(year_count gt 2004.856 ) and (year_count le 2004.955):	BEGIN ;#89  -  Nov 09 - Dec 14, 2004
pres_aeronet=0.993769

tr340=0.705989 & tr380=0.441811			; CIMEL #89 corrected for GSFC pressure
tr440=0.239505 & tr500=0.141753	; CIMEL #94 corrected for GSFC pressure
ln_wav=alog(0.1+[339.9,380.1,440.0,500.0])	; and lam plus 0.1 for vacuum wavelength scale
cimel=89 
v0_corr_cimel=[+0.000,+0.000,+0.000,+0.000] 	; [340,380,440,500] is not known for CIMEL #89                     
							END
(year_count gt 2004.955) and (year_count le 2004.99999):	BEGIN ;#94 -   Dec 15 - Dec 31, 2004
pres_aeronet=0.993769

tr340=0.705989 & tr380=0.445221  & tr440=0.239505 & tr500=0.141753		; CIMEL #94 corrected for GSFC pressure
ln_wav=alog(0.1+[339.9,379.4,440.0,500.0])	; and lam plus 0.1 for vacuum wavelength scale
cimel=94 
v0_corr_cimel=[+0.000,+0.000,+0.000,+0.000] 	; [340,380,440,500] is not known for CIMEL #94                     
								END

(year_count gt 2005.001 and year_count lt 2005.0793977):	BEGIN ;#101 - Jan 01, 2005 - Jan 28,2005 at Mauna Loa Observatory
;Date: Wed, 16 Feb 2005 17:18:40 -0500 
;To: krotkov <krotkov@chescat.gsfc.nasa.gov> 
;From: Tom Eck <teck@ltpmail.gsfc.nasa.gov> 
;Subject: Re: Fwd: V-naughts from the NASA UV-MFRSR Instrument at Mauna Loa 
; Hi Nick,
;Use Cimel #101 for the time period from Dec 08, 2004 through Jan 28, 2005. This is the Cimel Mauna Loa data on the web that you can download.

cimel=101

;From: Ilya Slutsker <ilya@ltpmail.gsfc.nasa.gov> 
;Subject: 101 at Mauna Loa 
;Wave = 1.018700   Rayleigh = 0.005253  at elevation 3397.000000  in Mauna_Loa
;Wave = 0.869300   Rayleigh = 0.009946  at elevation 3397.000000  in Mauna_Loa
;Wave = 0.676500   Rayleigh = 0.027387  at elevation 3397.000000  in Mauna_Loa
;Wave = 0.440500   Rayleigh = 0.157761  at elevation 3397.000000  in Mauna_Loa
;Wave = 0.500600   Rayleigh = 0.093284  at elevation 3397.000000  in Mauna_Loa
;Wave = 0.936200   Rayleigh = 0.007378  at elevation 3397.000000  in Mauna_Loa
;Wave = 0.379500   Rayleigh = 0.292668  at elevation 3397.000000  in Mauna_Loa (p/p0=0.654)
;Wave = 0.340000   Rayleigh = 0.464019  at elevation 3397.000000  in Mauna_Loa (p/p0=0.654)
;Ilya Slutsker

;Date: Mon, 28 Feb 2005 16:06:47 -0500 
;To: krotkov <krotkov@chescat.gsfc.nasa.gov> 
;From: Tom Eck <teck@ltpmail.gsfc.nasa.gov> 
;Here are the equations that we use to compute atmospheric pressure as a function of altitude for AERONET. 
;The Version 1 equation is what we use now, and Version 2 equation will be used with NCEP/NCAR reanalysis (6-hour) pressure in Version 2.0 data.
;- So for Mauna Loa we now have (Version 1):  662.6 mb (P/P0=0.654)
;- So for Mauna Loa we will have (Version 2): ~667.8 mb  
;(for 1013.25 mb std sea level pressure; but in reality the Verison 2 site pressure will vary with the actual surface pressure 6-hour variation.)

pres_aeronet=0.654
tr340=0.464019 & tr380=0.292668 & tr440=0.157761 & tr500=0.093284	; AERONET Rayleigh subrtarction at Mauna Loa pressure 662.6 mb (P/P0=0.653)
ln_wav=alog(0.1+[340.0,379.5,440.5,500.6])	; and lam plus 0.1 for vacuum wavelength scale

; V0 correction is determined manually by adjusting AOT diurnal dependence at 340,380,440,500nm when the CIMEL is calibrated at MAuna Loa)
;	This adjustment will change after each re-calibration of CIMEL and/or AERONET data re-processing
;	Also these numbers should change for locations other than MAuna Loa !!!!
;v0_corr_cimel=[+0.011,+0.008,+0.001,+0.002] 	; [340,380,440,500] for CIMEL #101 at ML 05/1/20-22
v0_corr_cimel=[+0.000,+0.000,+0.000,+0.000] 	; [340,380,440,500] for CIMEL #101 at ML 05/1/20-22
							END

;CIMEL #89:		Jan29=29/365.25		March 12=70/365.25
(year_count ge 2005.0793977 and year_count lt 2005.194387):	BEGIN ;#89 - Jan 29, 2005 - March 11,2005 at Mauna Loa Observatory

;Date: Mon, 14 Mar 2005 16:38:47 -0500 
;From: Tom Eck <teck@ltpmail.gsfc.nasa.gov> 
;Subject: #89 data at MLO 
;Hi Nick,
;The data for Cimel #89 at Mauna Loa Observatory (MLO) from Jan 29 - Mar 11 has been reprocessed with the Langley calibrations from this time period applied.
;The data from Feb 21 - Mar 11, 2005 at MLO shows much less diurnal trends than the data before Feb 21. 
;This may be related to the performance of the Cimel robot. Misha reported that he found a problem with this robot at MLO a couple of days ago. 
;We are sending a replacement robot to MLO this week.

cimel=89 

;From: Ilya Slutsker <ilya@ltpmail.gsfc.nasa.gov> 
;Subject: Re: 89 at Mauna Loa ? 
;							CIMEL #89 
;Wave = 1.019800   Rayleigh = 0.005230  at elevation 3397.000000  in Mauna_Loa
;Wave = 0.869800   Rayleigh = 0.009923  at elevation 3397.000000  in Mauna_Loa
;Wave = 0.674200   Rayleigh = 0.027768  at elevation 3397.000000  in Mauna_Loa
;Wave = 0.440200   Rayleigh = 0.158205  at elevation 3397.000000  in Mauna_Loa
;Wave = 0.501600   Rayleigh = 0.092525  at elevation 3397.000000  in Mauna_Loa
;Wave = 0.936100   Rayleigh = 0.007381  at elevation 3397.000000  in Mauna_Loa
;Wave = 0.380100   Rayleigh = 0.290746  at elevation 3397.000000  in Mauna_Loa
;Wave = 0.340200   Rayleigh = 0.462870  at elevation 3397.000000  in Mauna_Loa
pres_aeronet=0.654
tr340=0.462870 & tr380=0.290746 & tr440=0.158205 & tr500=0.092525	; AERONET Rayleigh subrtarction for CIMEL #89 at Mauna Loa pressure 662.6 mb (P/P0=0.654)
ln_wav=alog(0.1+[340.2,380.1,440.2,501.6])	; CIMEL #89 wavelengths plus 0.1 for vacuum wavelength scale
v0_corr_cimel=[+0.000,+0.000,+0.000,+0.000]     ; [340,380,440,500] for CIMEL #89 at ML 05/1/29-05/03/11

								END
;CIMEL #37:		March 12=0.19165  - April 5=0.2601
(year_count ge 2005.19165   and year_count lt 2005.26283 ):	BEGIN ;#37 - March 12, 2005 - April 5,2005 at Mauna Loa Observatory
;Hi Nick,
;I will ask Dave Giles to investigate this, the data are there on demonstrat for March 12 - 24, 2005
;The Cimel at Mauna Loa from March 12 - April 5, '05 was #37, with a 
;new 340 nm filter from a different manufacturer. There is an apparent 
;problem with these 340 nm filters, possibly out of bandpass energy 
;leakage. The 340 nm AOD crosses over the 380 nm AOD every day as a 
;function of airmass.This Cimel #37 is not being considered an AERONET reference, and it 
;was sent directly from MLO to Australia mainly to transfer radiance 
;calibration from our GSFC sphere to an integrating sphere there.
;Tom

cimel=37

;Subject: Re: CIMEL #37 at Mauna Loa March 12 - April 5, 2005
;Wave = 1.019000   Rayleigh = 0.005246  at elevation 3397.000000  in Mauna_Loa
;Wave = 0.869200   Rayleigh = 0.009951  at elevation 3397.000000  in Mauna_Loa
;Wave = 0.674800   Rayleigh = 0.027668  at elevation 3397.000000  in Mauna_Loa
;Wave = 0.439700   Rayleigh = 0.158948  at elevation 3397.000000  in Mauna_Loa
;Wave = 0.500100   Rayleigh = 0.093667  at elevation 3397.000000  in Mauna_Loa
;Wave = 0.940700   Rayleigh = 0.007237  at elevation 3397.000000  in Mauna_Loa
;Wave = 0.379900   Rayleigh = 0.291385  at elevation 3397.000000  in Mauna_Loa
;Wave = 0.340000   Rayleigh = 0.464019  at elevation 3397.000000  in Mauna_Loa
pres_aeronet=0.654
tr340=0.464019 & tr380=0.291385 & tr440=0.158948 & tr500=0.093667	; AERONET Rayleigh subrtarction for CIMEL #37 at Mauna Loa pressure 662.6 mb (P/P0=0.654)
ln_wav=alog(0.1+[340.0,379.9,439.7,500.1])	; CIMEL #37 wavelengths plus 0.1 for vacuum wavelength scale
v0_corr_cimel=[+0.000,+0.000,+0.000,+0.000]     ; correction at [340,380,440,500] for CIMEL #37 at ML 05/3/12-05/04/05
 								END

;CIMEL #94 at Mauna Loa:		April 6 (2005.2628) - April 26 (2005.317591)
;Date: Tue, 3 May 2005 18:08:50 -0400 
;From: Tom Eck <teck@ltpmail.gsfc.nasa.gov> 
;You can also use the #94 CIMEL data at Mauna Loa from April 6 - April 26, 2005.

(year_count ge 2005.2628  and year_count lt 2005.3203 ):	BEGIN ;#94 - April 6 , 2005 - April 26,2005 at Mauna Loa Observatory
cimel=94	 
;Wave = 1.021000   Rayleigh = 0.005205  at elevation 3397.000000  in Mauna_Loa
;Wave = 0.869200   Rayleigh = 0.009951  at elevation 3397.000000  in Mauna_Loa
;Wave = 0.674400   Rayleigh = 0.027735  at elevation 3397.000000  in Mauna_Loa
;Wave = 0.440300   Rayleigh = 0.158056  at elevation 3397.000000  in Mauna_Loa
;Wave = 0.499500   Rayleigh = 0.094128  at elevation 3397.000000  in Mauna_Loa
;Wave = 0.935000   Rayleigh = 0.007416  at elevation 3397.000000  in Mauna_Loa
;Wave = 0.379600   Rayleigh = 0.292346  at elevation 3397.000000  in Mauna_Loa
;Wave = 0.339900   Rayleigh = 0.464596  at elevation 3397.000000  in Mauna_Loa
pres_aeronet=0.654
tr340=0.464596 & tr380=0.292346 & tr440=0.158056 & tr500=0.094128	; AERONET Rayleigh subrtarction for CIMEL #94 at Mauna Loa pressure 662.6 mb (P/P0=0.654)
ln_wav=alog(0.1+[339.9,379.6,440.3,499.5])	; CIMEL #94 wavelengths plus 0.1 for vacuum wavelength scale
v0_corr_cimel=[+0.000,+0.000,+0.000,+0.000]     ; correction at [340,380,440,500] for CIMEL #94 at ML 05/3/12-05/04/05
 								END

(year_count ge 2005.3203  and year_count lt 2005.3477):	BEGIN ; CIMEL #181 at Mauna Loa:  April 27 (2005.3203) - May 6 
cimel=181 
;Date: Fri, 20 May 2005 11:35:41 -0400 
;To: krotkov <krotkov@chescat.gsfc.nasa.gov> 
;From: Ilya Slutsker <ilya@ltpmail.gsfc.nasa.gov> 
;Subject: 181 at Mauna Loa 
;Apr 27 -> May 6 2005 (#181)
;Wave = 1.019400   Rayleigh = 0.005238  at elevation 3397.000000  in Mauna_Loa
;Wave = 0.870400   Rayleigh = 0.009896  at elevation 3397.000000  in Mauna_Loa
;Wave = 0.675300   Rayleigh = 0.027585  at elevation 3397.000000  in Mauna_Loa
;Wave = 0.439600   Rayleigh = 0.159097  at elevation 3397.000000  in Mauna_Loa
;Wave = 0.499800   Rayleigh = 0.093897  at elevation 3397.000000  in Mauna_Loa
;Wave = 0.941100   Rayleigh = 0.007225  at elevation 3397.000000  in Mauna_Loa
;Wave = 0.379800   Rayleigh = 0.291705  at elevation 3397.000000  in Mauna_Loa
;Wave = 0.339300   Rayleigh = 0.468071  at elevation 3397.000000  in Mauna_Loa
pres_aeronet=0.654
tr340=0.468071 & tr380=0.291705 & tr440=0.159097 & tr500=0.093897	; AERONET Rayleigh subrtarction for CIMEL #181 at Mauna Loa pressure 662.6 mb (P/P0=0.654)
ln_wav=alog(0.1+[339.3,379.8,439.6,499.8])	; CIMEL #181 wavelengths plus 0.1 for vacuum wavelength scale
v0_corr_cimel=[+0.000,+0.000,+0.000,+0.000]     ; correction at [340,380,440,500] for CIMEL #181 at ML 05/4/27-05/05/06
 								END
;Date: Thu, 5 Jan 2006 16:18:49 -0500
;To: Nick Krotkov <krotkov@chescat.gsfc.nasa.gov>
;From: Tom Eck <teck@ltpmail.gsfc.nasa.gov>
;The Cimels currently being used GSFC on the AERONET web site:
;#101 WAS THE MASTER FROM JULY 20-31, 2005 (2005.5503 - 2005.5804 )
;Date: Thu, 9 Feb 2006 13:48:49 -0500 
;To: Nick Krotkov <krotkov@chescat.gsfc.nasa.gov> 
;From: Tom Eck <teck@ltpmail.gsfc.nasa.gov> 
;Subject: Re: master CIMELs at GSFC ? - UPDATED 
;To be clear: the Cimels currently being used for GSFC on the AERONET web site:
;#101 - Aug 1 - Sep 19, 2005  ( 2005.5831 - 2005.7173 )
;#37 - Sep 20 - Dec  6, 2005  ( 2005.7201 - 2005.9309 )
;#101 - Dec 7, 2005 - present ( 2005.9336 - 2006.1095 )
;Tom

(year_count ge 2005.5460  and year_count le 2005.7173):	BEGIN ; CIMEL #101 at GSFC:  Jul 20 (2005.5503) - Sep 19 (2005.7173 )
cimel=101  & pres_aeronet=0.993769
;Thanks for info. I assume I could use the same rayleigh subtractions for #101 as before.  ;YES AS LONG AS YOU USE VERSION 1.
tr340=0.705309 & tr380=0.444855 & tr440=0.239797 & tr500=0.141792	; #101 (version 1)  Rayleigh subrtarction at GSFC      pressure 662.6 mb (P/P0=0.993769)
ln_wav=alog(0.1+[340.0,379.5,440.5,500.6])	; and lam plus 0.1 for vacuum wavelength scale
; V0 correction is determined manually by adjusting AOT diurnal dependence at 340,380,440,500nm when the CIMEL is calibrated at MAuna Loa)
;	This adjustment will change after each re-calibration of CIMEL and/or AERONET data re-processing
;	Also these numbers should change for locations other than MAuna Loa !!!!
;v0_corr_cimel=[+0.011,+0.008,+0.001,+0.002] 	; [340,380,440,500] for CIMEL #101 at ML 05/1/20-22
v0_corr_cimel=[+0.000,+0.000,+0.000,+0.000] 	; [340,380,440,500] for CIMEL #101 at GSFC 05/7/20-06/01/05
							END

(year_count ge 2005.7201  and year_count le 2005.9309):	BEGIN ; CIMEL #37 - Sep 20 - Dec  6, 2005  ( 2005.7201 - 2005.9309 )
cimel=37  & pres_aeronet=0.993769
tr340=0.705088 & tr380=0.442767 & tr440=0.241525 & tr500=0.142329  ; AERONET Rayleigh subrtarction for CIMEL #37 at GSFC (P/P0=0.993769 )
ln_wav=alog(0.1+[340.0,379.9,439.7,500.1])      ; CIMEL #37 wavelengths plus 0.1 for vacuum wavelength scale
v0_corr_cimel=[+0.000,+0.000,+0.000,+0.000]     ; correction at [340,380,440,500] for CIMEL #37 
							END

;(year_count ge 2005.9336  and year_count lt 2006.3095):	BEGIN ; #101 at GSFC - Dec 7, 2005 - present ( 2005.9336 - 2006.1095 )              
;cimel=101  & pres_aeronet=0.993769
;;Thanks for info. I assume I could use the same rayleigh subtractions for #101 as before.  ;YES AS LONG AS YOU USE VERSION 1.
;tr340=0.705309 & tr380=0.444855 & tr440=0.239797 & tr500=0.141792	; #101 (version 1)  Rayleigh subrtarction at GSFC pressure (P/P0=0.993769)
;ln_wav=alog(0.1+[340.0,379.5,440.5,500.6])	; and lam plus 0.1 for vacuum wavelength scale
;v0_corr_cimel=[+0.000,+0.000,+0.000,+0.000] 	; [340,380,440,500] for CIMEL #101 at GSFC 05/7/20-06/01/05
;							END

(year_count ge 2006.0000  ):	BEGIN ; #4 at Richland 2006 - April 25 -    
;Subject: 4 in Richland
;Date: Fri, 20 Apr 2007 17:48:00 -0400
;Wave =3D 1.020800   Rayleigh =3D 0.007844  at elevation 123.000000  in Rich=
;Wave =3D 0.868900   Rayleigh =3D 0.015004  at elevation 123.000000  in Rich=
;Wave =3D 0.675200   Rayleigh =3D 0.041562  at elevation 123.000000  in Rich=
;Wave =3D 0.440000   Rayleigh =3D 0.238667  at elevation 123.000000  in Rich=
;Wave =3D 0.500000   Rayleigh =3D 0.141156  at elevation 123.000000  in Rich=
;Wave =3D 0.937200   Rayleigh =3D 0.011062  at elevation 123.000000  in Rich=
;Wave =3D 0.380000   Rayleigh =3D 0.438278  at elevation 123.000000  in Rich=
;Wave =3D 0.339900   Rayleigh =3D 0.699575  at elevation 123.000000  in Rich=

cimel=4  & pres_aeronet=0.990
tr340=0.699575 & tr380=0.438278 & tr440= 0.238667 & tr500=0.141156	; #101 (version 1)  Rayleigh subrtarction at GSFC pressure (P/P0=0.993769)
ln_wav=alog(0.1+[339.9,380.0,440.0,500.0])	; and lam plus 0.1 for vacuum wavelength scale
v0_corr_cimel=[+0.000,+0.000,+0.000,+0.000] 	; [340,380,440,500] for CIMEL #4 at Richland on April 2006
							END




ELSE: 								BEGIN
print,'year_count has illegal value:	',year_count
cimel=-999
stop
								END
ENDCASE



;		No corrections to AERONET AOT
aer340cor     =aeronet_aot(0)
aer380cor     =aeronet_aot(1)
aer440cor     =aeronet_aot(2)
aer500cor     =aeronet_aot(3)

;	Optional NO2 correction
IF no2_corr eq 'yes' THEN BEGIN			; subtract 1 DU tau_NO2 from AERONET AOT
print,'NO2 correction:'
aer340cor     =aeronet_aot(0)-0.0109
aer380cor     =aeronet_aot(1)-0.0168
aer440cor     =aeronet_aot(2)-0.0136
aer500cor     =aeronet_aot(3)-0.0061
ENDIF

delta_pres=(1.0 - rel_press/pres_aeronet) 	;     AERONET  CIMEL specific pressure and V0 correction
IF pressure_corr eq 'yes' THEN BEGIN		
aer340cor     =aer340cor +tr340*delta_pres > 0.0001	; if aer340cor < 0.0001 then aer340cor=0.0001
aer380cor     =aer380cor +tr380*delta_pres > 0.0001	; if aer380cor < 0.0001 then aer340cor=0.0001
aer440cor     =aer440cor +tr440*delta_pres > 0.0001	; if aer440cor < 0.0001 then aer340cor=0.0001
aer500cor     =aer500cor +tr500*delta_pres > 0.0001	; if aer500cor < 0.0001 then aer340cor=0.0001

ENDIF		 				; END: Pressure correction of AERONET AOT data

IF v0_corr       eq 'yes' THEN BEGIN		;	CIMEL V0 correction
aer340cor     =aer340cor +v0_corr_cimel(0)/am
aer380cor     =aer380cor +v0_corr_cimel(1)/am
aer440cor     =aer440cor +v0_corr_cimel(2)/am
aer500cor     =aer500cor +v0_corr_cimel(3)/am
ENDIF		 				; END: V0 correction                              


ln_aot=alog([aer340cor,aer380cor,aer440cor,aer500cor] )           ; Corrected AERONET AOT



;	Spectral extrapolation:


if ifit eq 2 then begin		; Quadratic interpolation

; ifit=2 and cimel_chan=3  - Lagrangian quadratic extrapolation using l0_fit,l1_fit and l2_fit
; ifit=2 and cimel_chan=4  - quadratic least square extrapolation

IF (cimel_chan eq 4 ) THEN BEGIN
coe_fit=poly_fit(ln_wav,ln_aot,ifit,yfit,/double)		; standard LSF [340,380,440,500]
;yf =coe_fit(0) + coe_fit(1)*ln_wav+ coe_fit(2)*ln_wav*ln_wav
for i=0,nlam-1 do aot_mfrsr(i)=exp(coe_fit(0) + coe_fit(1)*ln_wav_mfrsr(i) + coe_fit(2)*ln_wav_mfrsr(i)*ln_wav_mfrsr(i))
ENDIF

IF (cimel_chan eq 3 ) THEN BEGIN
ind_fit=[l0_fit,l1_fit,l2_fit]
coe_fit=poly_fit(ln_wav(ind_fit),ln_aot(ind_fit),ifit,yfit,/double)		; Lagrange interpolation from [l0_fit,l1_fit,l2_fit]
;yf =coe_fit(0) + coe_fit(1)*ln_wav+ coe_fit(2)*ln_wav*ln_wav
for i=0,nlam-1 do aot_mfrsr(i)=exp(coe_fit(0) + coe_fit(1)*ln_wav_mfrsr(i) + coe_fit(2)*ln_wav_mfrsr(i)*ln_wav_mfrsr(i))
ENDIF


endif else begin	; Linear interpolation (l0_fit,l1_fit)

;	else - linear extrapolation at 2 wavelengths (340, 380), (380,440), (440,500)

coe_fit=dblarr(2)
;		(l0,l1  ):
coe_fit(0)=(ln_aot(l0_fit)*ln_wav(l1_fit)-ln_aot(l1_fit)*ln_wav(l0_fit))/(ln_wav(l1_fit)-ln_wav(l0_fit)) 
coe_fit(1)=(ln_aot(l0_fit)-ln_aot(l1_fit))/(ln_wav(l0_fit)-ln_wav(l1_fit))

;		(340,380):
;coe_fit(0)=(ln_aot(0)*ln_wav(1)-ln_aot(1)*ln_wav(0))/(ln_wav(1)-ln_wav(0)) 
;coe_fit(1)=(ln_aot(0)-ln_aot(1))/(ln_wav(0)-ln_wav(1))

IF (year_count ge 2004.5859) and (year_count lt 2004.753 ) THEN BEGIN
coe_fit(0)=(ln_aot(1)*ln_wav(2)-ln_aot(2)*ln_wav(1))/(ln_wav(2)-ln_wav(1))  ; For CIMEL 303 at UAE need to avoid 340channel 
coe_fit(1)=(ln_aot(1)-ln_aot(2))/(ln_wav(1)-ln_wav(2))	;  linear extrapolation of AERONET [380,440]
ENDIF


for i=0,nlam-1 do aot_mfrsr(i)=exp(coe_fit(0) + coe_fit(1)*ln_wav_mfrsr(i))

endelse

plot_aot_spec,y_input,m_input,d_input,year_count_input,no2_corr,mode,count_day,time,am,[340.,380.,440.,500.],aeronet_aot,aer340cor,aer380cor,aer440cor,aer500cor,delta_aot_fit,sigma_aot_fit,l0_fit,l1_fit


return
end
