pro plot_aot_spec,y_input,m_input,d_input,year_count,no2_corr,mode,count_day,time,am,wave_aeronet,aot_aeronet,aer340cor,aer380cor,aer440cor,aer500cor,dtau02,sigma_aot_fit,l0_fit,l1_fit

;  Plot pressure corrected AERONET AOT and spectral interpolations

;	WARNINGS:
;  lam_mfrsr(0) has been changed to 440nm

cd_input=string(d_input,format='(i2)') & cm_input=string(m_input,format='(i2)')

x='' 
ctitle='Extrapolated AERONET AOT at GSFC  '+string(y_input,format='(i4)')+string(m_input,format='(i5)')+string(d_input,format='(i3)')+string(time,format='(f9.2)')

;		AOT spectral plot
;aot_aer=aot_aeronet					; uncorrected AERONET AOT
aot_aer=[aer340cor,aer380cor,aer440cor,aer500cor]	; corrected AERONET AOT


xleg=340.	; x coordinate to start legend

if mode eq 'screen' then begin
set_plot,'X' & device,pseudo_color=8
endif else begin
set_plot,'PS' & device,/color,/landscape,filename='aot_spec'+string(y_input,format='(i4)')+strcompress(cm_input,/remove_all)+strcompress(cd_input,/remove_all)
endelse

;title_plot
;               Blue                    Red
;        0  1   2   3   4   5  6    7   8   9   10  11  12  13  14
;       -30 -25 -20 -15 -10 -5      0  +5  +10 +15 +20 +25 +30 +35
rr = [255,000,000,000,000,100,150,000,255,255,255,255,200,150,000]
gg = [255,000,050,100,150,200,220,240,230,150,100,060,020,000,000]
bb = [255,150,240,255,255,255,255,000,230,150,100,060,020,000,000]
col=[0,2,9,11,13,14]

!p.background=0

tvlct,rr,gg,bb
!p.thick=1
!p.charsize=1.1
!p.charthick=1
!x.thick=3
!y.thick=4



;			PLOT

xct='Wavelength, nm' & xmin=290.  & xmax=550. &  wave=findgen(100)*2 + 290.
aot=wave/wave*1.0 & yct='AERONET extrapolated AOT/AOT(380)'  & ymin=0.5  & ymax=1.8 &  ycv0av=0.50 & ycv0sig=0.50
plot_oo,wave,aot,color=14,/nodata, title=ctitle,$
xticks=2, xtickv=[300.,400.,500.],$
ytitle=yct, yrange=[ymin,ymax],ystyle=1,$
xtitle=xct,xrange=[xmin,xmax],/xs
!p.color=14
xyouts,460,1.50,'Air mass=',size=1.5 & xyouts,510,1.5,string(am,format='(f5.3)' ),size=1.5
;xyouts,350,0.59,'<AOT>=' & xyouts,360.,0.59,string(mean_aot368,format='(f6.3)' )


!p.color=11        ;	original	AERONET
aot_aer_err=[0.02,0.02,0.01,0.01]
;oplot,wave_aeronet,aot_aer,psym=2,sym=1.5
oploterr,wave_aeronet,aot_aer/aot_aer(1),aot_aer_err
xyouts,386,1.0,'!4s!x!d380!n=',charsize=1.5 &  xyouts,415,1.0,string(aot_aer(1),format='(f5.2)'),charsize=1.5


;					MFRSR
lam_mfrsr=[440.,305.,311.,317.,325.,332.,368.]  ;lam_mfrsr=[300.,305.,311.,317.,325.,332.,368.] 
ln_w_mfrsr=alog(lam_mfrsr)


!p.color=3		; 2nd degree fitted AERONET
ln_aot=alog(aot_aer) & ln_wav=alog(wave_aeronet)
;print,'aot_aer(corr)' & print,aot_aer
;print,'aot_aeronet' & print,aot_aeronet

coe_fit=poly_fit(ln_wav,ln_aot,2,yfit,y_err,sigma_aot_fit,corrm,/double)
;print,'2nd degree: coe_fit='	& print,coe_fit
yf =exp(coe_fit(0) + coe_fit(1)*ln_wav+ coe_fit(2)*ln_wav*ln_wav)
oplot,wave_aeronet,yf/aot_aer(1),psym=4,sym=1.0
ln_wav=alog(findgen(120)*2.+280.)
yf =exp(coe_fit(0) + coe_fit(1)*ln_wav+ coe_fit(2)*ln_wav*ln_wav)
oplot,exp(ln_wav),yf/aot_aer(1),line=0             

;		Calculate aot at mfrsr wavelengths
yf_mfrsr_2 =exp(coe_fit(0) + coe_fit(1)*ln_w_mfrsr+ coe_fit(2)*ln_w_mfrsr*ln_w_mfrsr)
;print,sigma_aot_fit,aot_aer(1),sigma_aot_fit/aot_aer(1)
xyouts,390,0.6,'!4r!ds!n!x/!4s!d380!n!x=' & xyouts,420,0.6,string(sigma_aot_fit/aot_aer(1),format='(f5.2)')

!p.color=7		; 1nd degree fitted AERONET atl0_fit and l1_fit	[340,380,440,500]

ln_aot=alog(aot_aer) & ln_wav=alog(wave_aeronet) & linear_fit,ln_wav,ln_aot,[l0_fit,l1_fit],coe_fit,aotm_aer_fit
oplot,wave_aeronet(l0_fit:l1_fit),aotm_aer_fit(l0_fit:l1_fit)/aot_aer(1),psym=6,sym=1.2
alpha=-(ln_aot(l0_fit)-ln_aot(l1_fit) )/(ln_wav(l0_fit)-ln_wav(l1_fit) )

xyouts,exp(ln_wav(l0_fit)),exp(ln_aot(l0_fit))/aot_aer(1),'!4a!x='  & xyouts,395,1.06,string(alpha,format='(f6.2)')		; alpha[340,380]
;xyouts,380,1.06,'!4a!x='  & xyouts,395,1.06,string(alpha,format='(f6.2)')		; alpha[340,380]

ln_wav=alog(findgen(120)*2.+280.)
yf =exp(coe_fit(0) + coe_fit(1)*ln_wav )
oplot,exp(ln_wav),yf/aot_aer(1),line=2            ;	interpolation [340,380]


!p.color=1		; 1st degree fitted AERONET [380,440,500]
ln_aot=alog(aot_aer) & ln_wav=alog(wave_aeronet)
coe_fit=poly_fit(ln_wav(1:3),ln_aot(1:3),1,yfit,y_err,sigma_aot_fit,corrm,/double)
yf =exp(coe_fit(0) + coe_fit(1)*ln_wav)
;yf =exp(coe_fit(0) + coe_fit(1)*ln_wav+ coe_fit(2)*ln_wav*ln_wav)
oplot,wave_aeronet(1:3),yf(1:3)/aot_aer(1),psym=4,sym=1.5
i1=1 & i2=2
alpha=-(ln_aot(i1)-ln_aot(i2) )/(ln_wav(i1)-ln_wav(i2) )
xyouts,385,0.9 ,'!4a!x='  & xyouts,395,0.90,string(alpha,format='(f5.2)')	;	alpha[380,440]
ln_wav=alog(findgen(120)*2.+280.)
yf =exp(coe_fit(0) + coe_fit(1)*ln_wav)
;yf =exp(coe_fit(0) + coe_fit(1)*ln_wav+ coe_fit(2)*ln_wav*ln_wav)
oplot,exp(ln_wav),yf/aot_aer(1),line=1             
!p.color=1		; Difference between 1st and 2nd degree fitting at UV-MFRSR wavelengths
yf_mfrsr_1 =exp(coe_fit(0) + coe_fit(1)*ln_w_mfrsr)  ; Calculate aot at mfrsr wavelengths

dtau02=yf_mfrsr_1-yf_mfrsr_2
xyouts,340,1.3,'Lin-Quad=' & xyouts,370.,1.3,string(dtau02(6),format='(f6.3)'),size=2.0
;print,'yf_mfrsr_1' &  print,yf_mfrsr_1 &  print,'yf_mfrsr_2' &  print,yf_mfrsr_2

plots,[325,325],[ymin,ymax]
xyouts,305.,0.52,string(dtau02(4),format='(f6.3)')
plots,[332,332],[ymin,ymax]
xyouts,335.,0.66,string(dtau02(5),format='(f6.3)')
plots,[368,368],[ymin,ymax]
xyouts,370.,0.75,string(dtau02(6),format='(f6.3)')
plots,[440,440],[ymin,ymax]
xyouts,442.,0.75,string(dtau02(0),format='(f6.3)')



!p.color=11
;IF no2_corr eq 'yes' THEN xyouts,440,1.50,'1DU NO!d2!n subtraction'  ELSE xyouts,440,1.50,'no NO!d2!n subtraction'

;read,x

if mode ne 'screen' then device,/close
;
return
end
