pro plot_chan_srf,ihead,ozone,pres_rel,airmass,mode,chan,w_vac,srf,err_srf,solv_w,beta_w,alpha_w,$
tau_ray_eff,tau_aer_eff,tau_oz_eff,l_rad

xmin=min(w_vac)-1.0  & xmax=max(w_vac)+1.0

;                                       PLOT
if mode eq 'screen' then begin
set_plot,'X' & device,pseudo_color=8
endif else begin
set_plot,'PS' & device,/color,/landscape,filename='GSFC_F391_SRF'+chan+'.ps'
endelse

ymin=0.00005 & ymax=4 


;			PLOT
;       PLOT
;               Blue                    Red
;        0  1   2   3   4   5  6    7   8   9   10  11  12  13  14
;       -30 -25 -20 -15 -10 -5      0  +5  +10 +15 +20 +25 +30 +35
rr = [255,000,000,000,000,100,150,000,255,255,255,255,200,150,000]
gg = [255,000,050,100,150,200,220,240,230,150,100,060,020,000,000]
bb = [255,150,240,255,255,255,255,000,230,150,100,060,020,000,000]
col=[0,2,9,11,13,14]
!p.background=0

tvlct,rr,gg,bb 
!p.thick=1
!p.charsize=1.1
!p.charthick=1
!x.thick=3
!y.thick=4


plot_io,w_vac,srf,/nodata,color=14,$
title='Normalized SRF at '+chan+'  UV-MFRSR  head'+ihead,$
xtitle='Wavelength (vacuum), nm',xrange=[xmin,xmax],/xstyle,$
yrange=[ymin,ymax],/ystyle,ytitle='Spectral response Function (SRF), nm!u-1!n'


!p.color=13  &  oploterr,w_vac,srf,err_srf ;	srf shifted to vac wavelengths
nw_vac=n_elements(w_vac) ;& print,'nw_vac=',nw_vac
w_vac_min=min(w_vac) & plots,[w_vac_min,w_vac_min],[0.01,0.07] & xyouts,w_vac_min-0.5,0.10,'!4k!x!dmin!n'
w_vac_max=max(w_vac) & plots,[w_vac_max,w_vac_max],[0.01,0.07] & xyouts,w_vac_max,0.10,'!4k!x!dmax!n'

!p.color=3
oplot,w_vac,solv_w    ,line=0
oplot,w_vac,solv_w*srf,line=0
print,w_vac
print,solv_w
print,srf
e0=int_tabulated(w_vac,solv_w*srf) & print,'e0=',e0
ce0='<E!dtop!n>='+string(e0,format='(f5.2)')+' Wm!u-2!nnm!u-1!n' & xyouts,w_vac_min+0.,1.9,ce0 

;print,'w_vac=',w_vac


!p.color=7	;		Rayleigh at srf vac wavelengths
tau_ray=pres_rel*beta_w
oplot,w_vac,tau_ray,psym=-1

!p.color=1		; ozone absorption
tau_oz=0.001*ozone*alpha_w
;print,'tau_oz:' &  print,tau_oz                    
oplot,w_vac,tau_oz,psym=-2

; 	Aerosol extinction
tau_aer=36.8/w_vac
;print,'tau_aer:' &  print,tau_aer                   

;	No   weighted airmass calculation

!p.color=11	;		Total extinction
t_spec=exp(-airmass*(tau_ray + tau_aer +tau_oz))	; calculated spectral transmittance
;oplot,w_vac,t_spec,psym=1 
oplot,w_vac,t_spec*solv_w*srf

e_bot=int_tabulated(w_vac,t_spec*solv_w*srf)  & print,'e_bot=',e_bot
ce_bot='<E!dbot!n>='+string(e_bot,format='(f5.3)')+' Wm!u-2!nnm!u-1!n' & xyouts,w_vac_min-1.0,0.00020,ce_bot 

t_meas=e_bot/e0		; "Measured transmittance"
print,'Transmittance=',t_meas  
;plots,[w_vac_min,w_vac_max],t_meas*[1,1]

print,'Airmass=',airmass
print,'Ozone=',ozone
print,'Pressure=',pres_rel
print,'E_bot=',e_bot    

;	Flux weighted (effective) wavelength
l_eff=int_tabulated(w_vac,w_vac*t_spec*solv_w*srf)/e_bot 
!p.color=1 &  plots,[l_eff,l_eff],[0.001,0.07] & xyouts,l_eff,0.00050,'!4k!x!deff!n'

;			Equivalent Radiative Wavelength
l_rad=interpol(double(w_vac),double(t_spec),double(t_meas)) & print,'			L_eff=',l_rad

if  abs(l_rad(0)-l_eff) gt 0.5  then begin	; check closeness to l_eff
print,'!!! l_rad too far from l_eff !!!'  & print,l_rad(0),l_eff

for i=1,nw_vac-5 do begin	; start removing shorter wavelengths iteratively 
l_rad=interpol(double(w_vac(i:nw_vac-1)),double(t_spec(i:nw_vac-1)),double(t_meas)) 
print,'l_rad,l_eff',i,l_rad,l_eff
if  abs(l_rad(0)-l_eff) le 0.5  then goto,quit	; check l_eff closiness            
endfor

print,'	!!! Fails to find L_rad: L_rad=L_eff  '
l_rad=l_eff

endif 

quit:		; END L_eff calculation
!p.color=11
print,'w_vac_min,w_vac_max,l_eff,l_rad=',w_vac_min,w_vac(nw_vac-1),l_eff,l_rad(0)
plots,[l_rad(0),l_rad(0)],[0.001,0.07] & xyouts,l_rad(0)+0.1,0.030,'!4k!x!drad!n'

tau_ray_eff=interpol(tau_ray,w_vac,l_rad(0)) &  print,'tau_ray_eff=',tau_ray_eff
if tau_ray_eff(0) gt max(tau_ray) or tau_ray_eff(0) lt min(tau_ray) then begin & print,'	!!! tau_ray_eff outside boundaries: ' & print,tau_ray_eff(0),min(tau_ray),max(tau_ray)  & stop & endif 

tau_aer_eff=interpol(tau_aer,w_vac,l_rad(0)) &  print,'tau_aer_eff(0)=',tau_aer_eff(0)
if tau_aer_eff(0) gt max(tau_aer) or tau_aer_eff(0) lt min(tau_aer) then begin & print,'	!!! tau_aer_eff(0) outside boundaries !!!' & stop & endif
tau_oz_eff =interpol(tau_oz,w_vac,l_rad(0)) &  print,'tau_oz_eff(0)=',tau_oz_eff(0)
if tau_oz_eff(0) lt min(tau_oz) or tau_oz_eff(0) gt max(tau_oz) then begin & print,'	!!! tau_oz_eff(0) outside boundaries !!!' & stop & endif 


if mode ne 'screen' then device,/close
return
end
