;		MODIFICATIONS
;		May 3 2005: process only morning data at Mauna Loa between am=2-3 
;		March 7 2005: V0 correction: daot=(dlnV0)/am
;		March 3 2005: add plot_aot_spec
;		Feb 28 2005: General linear interpolation   
;		Feb 25 2005: add output for average tau_r, pressure , tau_oz, lam_eff, lam_rad and std
;		Feb 18 2005: UV-MFRSR #527 : include 440nm filter 
;		Feb 18 2005: UV-MFRSR #527 : Mauna Loa data
;		Feb 11 2005: diffuse voltage correction for scattered light into FOV (~8deg FA)
;				assume that diffuse correction does not depend on SZA

;chan='311nm' & mfrsr_nm_start=527
;chan='317nm' & mfrsr_nm_start=527
;chan='325nm' & mfrsr_nm_start=527
;chan='332nm' & mfrsr_nm_start=527
;chan='368nm' & mfrsr_nm_start=527 ; new UV-MFRSR head number 
chan='440nm' & mfrsr_nm_start=527  

;	OPEN existing calibration file to get calibration dates and times

;close,11 & openr,11,'/home/krotkov/SPIE04/AOT_COMP/v0_norm368nm.clear.batch'        
;close,11 & openr,11,'/home/krotkov/SPIE04/AOT_COMP/v0_norm368nm.clear391only'       
;a=' ' &  for i=0,1 do readf,11,a &  matchdata=fltarr(30)

time_tolerance=10.0 ; max time difference between AERONET and UV-MFRSR measurements [min] (in plot_lnv0)
;sza_max=70.	; restrict max SZA to minimize uncertainties in cosine correction and OT
;sza_min=50.	; restrict min SZA if necessary ( to check V0 variability due to seasonal changes in SZA)
;sza_max=82.0  & sza_min=0.	; whole solar day     (not restricted )                                                   

sza_max=70.529  & sza_min=60.	; Airmass range 3 - 2     (also change time 18-21 for Morning Langley calibrations at ML )                          

;pressure_corr='no'	; no pressure correction of AERONET AOT data
pressure_corr='yes'	;    pressure correction of AERONET AOT data

v0_corr='yes'	; CIMEL AOT correction (V0) see aeronet_aot_ext.pro for actual correction values (CIMEL specific !)
;v0_corr='no'	; CIMEL AOT correction (V0)  

;press_diff=2.0	; Pressure diff between Beltswille Location and roof of Bld 33 at GSFC
		; Beltsville ~ 70 asl; GSFC~70asl; Bld ~+20m: height diff ~20m => pres diff ~2mb (1 mbar for 10m) 
;press_diff=0.0	; UAE, top of MAARCO containe (10m asl)  [ Pressure/1013.25mb]
 press_diff=0.0  ; co-located pressure at Mauna Loa Observatory (3397m asl; P/P0=0.654)
					; P/P0=exp(-z/29.3/273.0)*1013.25=662.642mb - AERONET V1

no2_corr='no'	; only affects plot_aot routine
;no2_corr='yes'  ;  only affects plot_aot routine
;ifit=2			; quadratic AOT extrapolation
ifit=1 
l0_fit=2 & l1_fit=3 		; liner extrapolation ln(AOT) vs ln(lam) (440,500nm)
;l0_fit=0 & l1_fit=1 		; liner extrapolation ln(AOT) vs ln(lam) (340,380nm)
;leff_mode='static' 	;   static Leff
leff_mode='dynamic'
mode='screen'		; screen output
;mode='print'		; PostScrip output



print,'input 1 to skip reading merged MFRSR/AERONET file and ETS: ' & read,iskip1 &  if iskip1 eq 1 then goto,skip 


input_filename='/misc/ground_data/SHADOWBAND/RAW/Maunaloa/mfrsr.cimel.MLO.txt'     ;	cosine corrected voltages (see Becky Olson message 05/02/07)
;input_filename='/home/labow/Shadowband/UAE/test.cc.08.txt'     ;	cosine corrected voltages (see Becky Olson message 05/02/07)
reader_merged_ml,input_filename, chan,year,month,day,hour,minute,second,$ 
;reader_merged_ccvolt,input_filename, chan,year,month,day,hour,minute,second,$ 
sza,am,nm_chan,aot340,aot380,aot440,aot500,pres,ozone,toms_oz,toms_ler,delta_time

print,'end reading merged file'
skip:  


saveday='y' & cadday='y' 
mfrsr_nm=mfrsr_nm_start


;		Calibration daily (V0) file
header=  'cimel year mn day gmt1 gmt2 r2   PRES  AOT S_AOT INT_DIF  OZN  LER  N0  N1  V0_NORM ln(V0_N) sig    C0   sigmaC0 TAU    -C1   sigma  am1  am2  C0(am)  sigmaC0(am) sigma_fit(am)'
close,4 & openw,4,'v0_norm'+chan+'.clear'
printf,4,'V0_NORM using AERONET AOT'+chan+' 	and 		         Langley regression'
printf,4,header                                                                                                                                                             
;              Re-calibrated and filtered Irradiance file
close,5 & openw,5,'irradcal'+chan+'.clear'
printf,5,'AERONET calibrated AOT merged file at '+chan
header5=  'Ins year mn day hh mm ss   total   diffuse  dir_nor  V0_RAW  r2    sza    am     abs_pr OZONE  LER  AOT_AER    daot    saot  AOT_MFRSR TAU_RAY  TAU_OZ  TAU_TOT  L_DIR   L_eff'
printf,5,header5



;		MFRSR SECTRAL BAND MODEL
get_chan_spec,mfrsr_nm,chan,mode, w_vac_chan,srf,err_srf,solv_w,beta_w,alpha_w  ; SECTRAL BAND MODEL FOR for specific head and channel

stop

		next_day:		; return point for main day to day cycle

;readf,11,matchdata
;y_input=matchdata(1)
;m_input=matchdata(2)
;d_input=matchdata(3)

read,'enter year,month,day (yyyy,mm,dd) ',y_input,m_input,d_input

if (y_input eq 2004 and m_input ge 4 and mfrsr_nm ne 391) then begin
mfrsr_nm=391		; change head to 391 at the end of March, so need to change the band model
get_chan_spec,mfrsr_nm,chan,mode, w_vac_chan,srf,err_srf,solv_w,beta_w,alpha_w  ; SECTRAL BAND MODEL FOR for specific head and channel
endif

cd_input=string(d_input,format='(i2)') & cm_input=string(m_input,format='(i2)') 
;name_aot   ='aot'+chan+string(y_input,format='(i4)')+strcompress(cm_input,/remove_all)+strcompress(cd_input,/remove_all)
name_langley='langley'+chan+string(y_input,format='(i4)')+strcompress(cm_input,/remove_all)+strcompress(cd_input,/remove_all)
yymmdd=[y_input,m_input,d_input]  & doy=julday(yymmdd)  & print,'doy=',doy
;       -- correct for sun-earth distance
;       V0_RAW = V0_NORM / r2 : see /misc/jwscr1/krotkov/UVFLUX/source_timeseries/uv_flux_can_bsza_V8.f
         phase = 0.0172024238D0 * (double(doy)-3.4)
         r  = 1.0 - 0.0167*cos(phase)
         r2=r*r

year_count_input=double(y_input + doy/365.25)   & print,'year_count_input=',year_count_input   ; year count calculation
print,d_input,m_input,y_input
time_all=hour(*)+minute(*)/60.+ second(*)/3600.

;read,'Enter start time, End Time GMT: ',gmt_start,gmt_end
gmt_start=0.0 & gmt_end=24.	; whole day
;gmt_start=22.5 & gmt_end=23.	; am=1.3

;gmt_start=matchdata(4)
;gmt_end=matchdata(5)


;	Solar day at Hawaii runs from ~16UT on d_input till 4am d_input+1 

;w=where ((day eq d_input   and time_all(*) gt 16.00 )  OR  $	; whole day
;         (day eq d_input+1 and time_all(*) lt  4.00 ) $        ; whole day

w=where ((day eq d_input   and time_all(*) gt 18.00 )   $	; Morning only
            and (month eq m_input) and (year eq y_input) $
            and nm_chan(2,*) gt 0.0   $
            and time_all(*) ge gmt_start   $
            and time_all(*) le gmt_end     $
            and sza(*) ge sza_min	   $
            and sza(*) le sza_max, count_day)

print,'Number of daily data=',count_day
  if (count_day lt 5) then begin
  print,'Number of daily data less than 5'
  goto,next_day
  endif

   time1=hour(w)+minute(w)/60.+ second(w)/3600.

  day1=day(w)
  month1=month(w)
  hh1=hour(w) & mn1=minute(w) & ss1=second(w)
  year1=year(w)
  aot3401=aot340(w)
  aot5001=aot500(w)

pres1=pres(w) -press_diff  ;	 pres1=fltarr(count_day) & pres1(*)=pres(w(0)) -press_diff                         
rel_press=pres1/1013.25		; realtive to standard pressure at sea level
temp_pres1=moment(rel_press) & mean_psite=temp_pres1(0)  & sigma_psite=sqrt(temp_pres1(1))
print,'Mean daily site pressure [Atm]: ',mean_psite,'	St deviation: ',sigma_psite

ozone1=ozone(w) &  if ozone1(0) le 20. then ozone1=toms_oz(w) 	; fill in Brewer gaps with TOMS ozone data
temp_ozone1=moment(ozone1) & mean_ozone=temp_ozone1(0)  & sigma_ozone=sqrt(temp_ozone1(1))
print,'Mean daily ozone [DU]: ',mean_ozone,'	St deviation: ',sigma_ozone

toms_ler1=0.01*toms_ler(w) 	; TOMS LER                                      
temp_toms_ler1=moment(toms_ler1) & mean_toms_ler=temp_toms_ler1(0) 
print,'Mean daily toms_ler [DU]: ',mean_toms_ler

temp_aot3401=moment(aot3401) & mean_aot340=temp_aot3401(0)  & sigma_aot340=sqrt(temp_aot3401(1))
print,'Mean daily aot340 : ',mean_aot340,'	St deviation: ',sigma_aot340
temp_aot5001=moment(aot5001) & mean_aot500=temp_aot5001(0)  & sigma_aot500=sqrt(temp_aot5001(1))
print,'Mean daily aot500 : ',mean_aot500,'	St deviation: ',sigma_aot500


;	extract direct_normal irradiance only for specified DOY
  nm_chanb=reform(nm_chan(2,w)) & tot_irrchanb=reform(nm_chan(0,w)) & dif_irrchanb=reform(nm_chan(1,w)) 
  sza1=reform(sza(w)) & am1=reform(am(w)) 
   aot340b=reform(aot340(w)) & aer340cor=aot340b
   aot380b=reform(aot380(w)) & aer380cor=aot380b
   aot440b=reform(aot440(w)) & aer440cor=aot440b
   aot500b=reform(aot500(w)) & aer500cor=aot500b
   delta_time1=reform(delta_time(w))

totchanb=aot380b  	; total chan OT 
aotchanb=aot380b	; chan AOT
tau_raychanb=aot380b 	; chan Ray OT
tau_ozchanb=aot380b 	; chan ozone OT 
lnv0chan=aot340b	; chan ln(V0) data
daot_intchan=aot380b	; extrapolation difference between 2nd degree and 1st degree AOT extrapolation
saot_fit = aot380b	; sigma fit for 2nd degree polynomial fitting
w_dir=aot380b		; direct radiance equivalent wavelength
w_eff=aot380b		; bandpass effective  wavelength

;		Determine FOV correction to nm_chanb due to diffuse FOV scattered light
;read,'Input FOV diffuse light correction [P Russel et al JGR2004]: corr_fov=tau(true)/tau(apparent):	',corr_fov
corr_fov=1.0

for i=0,n_elements(aot340b)-1 do begin		; Main cycle through MFRSR daily measurements

aeronet_aot=[aot340b(i),aot380b(i),aot440b(i),aot500b(i)]

;  interpolation total TAU: T=(tau_aer+tau_NO2)+tau_ray+tau_ozone at w_vac_chan

print,'year_count_input=',year_count_input
get_tot_cp,mode,y_input,m_input,d_input,no2_corr,pressure_corr,chan,leff_mode,year_count_input,time1(i),am1(i),rel_press(i),ozone1(i),aeronet_aot,ifit,l0_fit,l1_fit,v0_corr,cimel,$
v0_corr_cimel, w_vac_chan,srf,err_srf,solv_w,beta_w,alpha_w, temp_r,temp_a,temp_oz,temp_tot,leff,l_rad,temp_aer340,temp_aer380,temp_aer440, temp_aer500,delta_aot_fit,sigma_aot_fit

aer340cor(i)=temp_aer340 & aer380cor(i)=temp_aer380 & aer440cor(i)=temp_aer440 & aer500cor(i)=temp_aer500	; AERONET corrected AOT


daot_intchan(i)=delta_aot_fit(6)	; interpolation difference between quadratic and linear extrapolation
saot_fit(i)=sigma_aot_fit	; sigma fit for 2nd degree polynomial fitting
aotchanb(i)=temp_a  & tau_raychanb(i)=temp_r & tau_ozchanb(i)=temp_oz &  totchanb(i)=temp_tot &  w_dir(i)=l_rad & w_eff(i)=leff
print,'temp_a,temp_r,temp_oz,temp_tot,l_rad     ' ,temp_a,temp_r,temp_oz,temp_tot,l_rad

;		INITIAL V0 estimoation (no corrections or filtering)
;lnv0chan(i)=alog(nm_chanb(i)) + am1(i)*totchanb(i)		;  individual RAW V0 estimates on a given day

;			Diffuse FOV correction of operational (cosine corrected) voltages
vn_oper=nm_chanb(i) & lnvn_oper=alog(vn_oper)              
lnv0chan(i)=lnvn_oper  + am1(i)*totchanb(i)/corr_fov	;  V0 estimoation with diffuse FOV correction: lnV0=lnVn(operational) + m*(tau_tot)/corr_fov
nm_chanb(i)=exp(lnv0chan(i)*(1.0 -corr_fov) + corr_fov*lnvn_oper) ;Direct normal voltage correction:     FOVcorr=exp(lnV0 (1-corr_fov) + corr_fov*lnVn(operational) )



endfor			; end daily cycle


temp_tau_raychanb=moment(tau_raychanb) & mean_temp_r=temp_tau_raychanb(0)  & sigma_temp_r=sqrt(temp_tau_raychanb(1))
temp_tau_ozchanb=moment(tau_ozchanb) & mean_temp_oz=temp_tau_ozchanb(0)  & sigma_temp_oz=sqrt(temp_tau_ozchanb(1))
temp_w_dir=moment(w_dir) & mean_l_rad=temp_w_dir(0)  & sigma_l_rad=sqrt(temp_w_dir(1))
temp_w_eff=moment(w_eff) & mean_l_eff=temp_w_eff(0)  & sigma_l_eff=sqrt(temp_w_eff(1))
temp_rel_press=moment(rel_press) & mean_rel_press=temp_rel_press(0)  & sigma_rel_press=sqrt(temp_rel_press(1))

temp_totchanb=moment(totchanb) & mean_totchan=temp_totchanb(0)  & sigma_totchan=sqrt(temp_totchanb(1))
temp_daot_intchan=moment(daot_intchan) & mean_daot_intchan=temp_daot_intchan(0)  & sigma_daot_intchan=sqrt(temp_daot_intchan(1))

print
print,chan
print,'Daily mean statistics'
print,'Mean values:'
print,'Pressure [atm] tau_oz	tau_ray	l_rad	l_eff'
print,mean_rel_press,mean_temp_oz,mean_temp_r,mean_l_rad, mean_l_eff
print,'STD'
print,sigma_rel_press,sigma_temp_oz,sigma_temp_r,sigma_l_rad,sigma_l_eff
print

;		Raw Langley plot
ctitle_langley='Langley plot at '+chan+',  GSFC   '+string(y_input,format='(i4)')+string(m_input,format='(i5)')+string(d_input,format='(i3)')
;plot_langley,mode,name_langley,ctitle_langley,count_day,r2,sza1,am1,nm_chanb,aotchanb,mean_ozone,mean_psite,pres1,time1,lnv0chan,totchanb,mean_lnv0chan, sigma_lnv0chan,mean_aotchan,langley_c0chan,sigma_c0chan,langley_c1chan,sigma_c1chan,langley_sigmachan
coe_fit=poly_fit(am1,alog(nm_chanb),1,v_fit,/double) 
;print,'Raw Langley lnV0', coe_fit(0)

;		V0 calibration plot
plot_lnv0_new,sza_min,sza_max,corr_fov,y_input,m_input,d_input,chan,mode,r2,count_day,time_tolerance,delta_time1,sza1,am1,nm_chanb,aotchanb,tau_raychanb,tau_ozchanb,mean_ozone,mean_toms_ler,mean_psite,rel_press,time1,lnv0chan,totchanb,$
count3,mean_lnv0chan, sigma_lnv0chan,mean_aotchan,langley_c0chan,sigma_c0chan,langley_c1chan,sigma_c1chan,langley_sigmachan,am1_lan,am2_lan,langley_c0chan_am,sigma_c0chan_am,langley_sigmachan_am,am1_am,am2_am,sig_aot_diff,w3,aotchan_mfrsr,aot340b,aot380b,aot440b,aot500b

;		AOT time plot
;plot_aot_time,cimel,v0_corr,v0_corr_cimel,pressure_corr,corr_fov,y_input,m_input,d_input,chan,mode,r2,count_day,time_tolerance,delta_time1,sza1,am1,aotchanb,mean_ozone,mean_toms_ler,mean_psite,rel_press,time1,mean_aotchan,sig_aot_diff,w3,aotchan_mfrsr,aot340b,aot380b,aot440b,aot500b,aer340cor,aer380cor,aer440cor,aer500cor


print,langley_c0chan_am+alog(r2),sigma_c0chan_am,langley_sigmachan_am,am1_am,am2_am


print & print
print,cimel,y_input,m_input,d_input,gmt_start,gmt_end,r2,mean_psite,mean_aotchan,sig_aot_diff,mean_daot_intchan,mean_ozone,mean_toms_ler,count_day,count3,r2*exp(mean_lnv0chan), mean_lnv0chan+alog(r2),sigma_lnv0chan,$
langley_c0chan+alog(r2),sigma_c0chan,mean_totchan,-langley_c1chan,langley_sigmachan,am1_lan,am2_lan,langley_c0chan_am+alog(r2),sigma_c0chan_am,langley_sigmachan_am,am1_am,am2_am,$
format='(i3,1x,i4,2(1x,i2),2(1x,f4.1),4(1x,f5.3),1x,f6.3,1x,i4,1x,f4.2,1x,2(1x,i3),2x,i5,3x,f5.3,1x,f6.4,3x,f5.3,1x,f6.4,1x,f6.3,1x,f6.3,1x,f6.4,1x,2(f4.2,1x),f6.3,2(1x,f6.4),2(1x,f3.1) )'

read,'save results in v0_normchan_clear file? y - yes, n - no:  ', saveday 
 if saveday eq 'n' then goto,next_day 
printf,4,cimel,y_input,m_input,d_input,gmt_start,gmt_end,r2,mean_psite,mean_aotchan,sig_aot_diff,mean_daot_intchan,mean_ozone,mean_toms_ler,count_day,count3,r2*exp(mean_lnv0chan), mean_lnv0chan+alog(r2),sigma_lnv0chan,$
langley_c0chan+alog(r2),sigma_c0chan,mean_totchan,-langley_c1chan,langley_sigmachan,am1_lan,am2_lan,langley_c0chan_am+alog(r2),sigma_c0chan_am,langley_sigmachan_am,am1_am,am2_am,$
format='(i3,1x,i4,2(1x,i2),2(1x,f4.1),3(1x,f5.3),1x,f6.4,1x,f6.3,1x,i4,1x,f4.2,1x,2(1x,i3),2x,i5,3x,f5.3,1x,f6.4,3x,f5.3,1x,f6.4,1x,f6.3,1x,f6.3,1x,f6.4,1x,2(f4.2,1x),f6.3,2(1x,f6.4),2(1x,f3.1) )'



count_day_good=n_elements(w3)
for i=0,count_day_good-1  do begin		; print cycle through MFRSR daily measurements
printf,5,mfrsr_nm,y_input,m_input,d_input,hh1(w3(i)),mn1(w3(i)),ss1(w3(i)),tot_irrchanb(w3(i)),dif_irrchanb(w3(i)),nm_chanb(w3(i)),exp(mean_lnv0chan),r2,sza1(w3(i)),am1(w3(i)),1013.25*rel_press(w3(i)),ozone1(w3(i)),mean_toms_ler,aotchanb(w3(i)),daot_intchan(w3(i)),saot_fit(w3(i)),aotchan_mfrsr(i),tau_raychanb(w3(i)),tau_ozchanb(w3(i)),totchanb(w3(i)),w_dir(w3(i)),w_eff(w3(i)),$
 format='(2(i4,1x),5(i2,1x),4(f8.2,1x),f5.3,1x,f6.3,1x,f6.4,1x,f7.2,1x,f5.1,1x,f4.2,1x,4(f7.4,1x),3(f8.6,1x),2(f8.4,1x))'

print,mfrsr_nm,y_input,m_input,d_input,hh1(w3(i)),mn1(w3(i)),ss1(w3(i)),tot_irrchanb(w3(i)),dif_irrchanb(w3(i)),nm_chanb(w3(i)),exp(mean_lnv0chan),r2,sza1(w3(i)),am1(w3(i)),1013.25*rel_press(w3(i)),ozone1(w3(i)),mean_toms_ler,aotchanb(w3(i)),daot_intchan(w3(i)),saot_fit(w3(i)),aotchan_mfrsr(i),tau_raychanb(w3(i)),tau_ozchanb(w3(i)),totchanb(w3(i)),w_dir(w3(i)),w_eff(w3(i)),$
 format='(2(i4,1x),5(i2,1x),4(f8.2,1x),f5.3,1x,f6.3,1x,f6.4,1x,f7.2,1x,f5.1,1x,f4.2,1x,4(f7.4,1x),3(f8.6,1x),2(f8.4,1x))'


endfor

read,'input additional day: y - yes, n - no:  ', cadday 
 if cadday eq 'y' then goto,next_day & close,4 & close,5

stop
end
